/*
 * AllupImpl.cc
 *
 * Copyright (c) 2003 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file AllupImpl.cc
 *
 * Implementation file for the AllupImpl class.
 */

#include "config.h"

#include <sys/types.h>
#include <signal.h>

#include <assert_pp.h>

#include "AllupImpl.hh"

#include "FactoryLibrary_ltdl.hh"

AllupImpl::AllupImpl(void)
{
}

AllupImpl::~AllupImpl(void)
{
}

edu::utah::pces::FactoryLibrary_ptr AllupImpl::OpenLibrary(const char *name)
    throw (edu::utah::pces::NoSuchLibrary,
	   CORBA::SystemException)
{
    edu::utah::pces::FactoryLibrary_var retval;

    /* Check the input and */
    if( name == NULL )
    {
	throw CORBA::BAD_PARAM();
    }

    /* Try opening the library and */
    retval = FactoryLibrary_ltdl::OpenLibrary(name);
    
    /* ... then add it to the map, if it is not already there. */
    if( this->ai_Libraries.count(name) == 0 )
    {
	this->ai_Libraries[name] = edu::utah::pces::FactoryLibrary::
	    _duplicate(retval);
    }
    
    return( retval._retn() );
}

edu::utah::pces::FactoryLibraryList *AllupImpl::Libraries(void)
    throw (CORBA::SystemException)
{
    edu::utah::pces::FactoryLibraryList_var retval;
    library_map_t::const_iterator pos;
    size_t list_size;
    int lpc;

    list_size = this->ai_Libraries.size();
    /* Create a sequence large enough to hold all the opened libraries and */
    retval = new edu::utah::pces::FactoryLibraryList(list_size);
    retval->length(list_size);
    /* ... then fill it in. */
    for( pos = this->ai_Libraries.begin(), lpc = 0;
	 pos != this->ai_Libraries.end();
	 pos++, lpc++ )
    {
	retval[lpc] = edu::utah::pces::FactoryLibrary::
	    _duplicate(pos->second.in());
    }
    return( retval._retn() );
}

void AllupImpl::Shutdown(void)
    throw (CORBA::SystemException)
{
    /* XXX Not sure if kill is the best way to do this... */
    kill(0, SIGTERM);
}
