/*
 * RealTimeTaskDelegateMixin.hh
 *
 * Copyright (c) 2003 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file RealTimeTaskDelegateMixin.hh
 *
 * Default implementations for the Broker::RealTimeTask methods.  Kind of a
 * hack really, but it works.
 *
 * @sa RealTimeTaskDelegateImpl.hh
 */

/** @copydoc Broker::RealTimeTask::Period */
virtual CORBA::ULong Period(void)
    throw (CORBA::SystemException)
{
    if( CORBA::is_nil(this->dm_RemoteObject) )
    {
	throw CORBA::BAD_INV_ORDER();
    }
    return( this->dm_RemoteObject->Period() );
};

/** @copydoc Broker::RealTimeTask::Deadline */
virtual CORBA::ULong Deadline(void)
    throw (CORBA::SystemException)
{
    if( CORBA::is_nil(this->dm_RemoteObject) )
    {
	throw CORBA::BAD_INV_ORDER();
    }
    return( this->dm_RemoteObject->Deadline() );
};

/** @copydoc Broker::RealTimeTask::GetComputeTime */
virtual CORBA::ULong GetComputeTime(void)
    throw (CORBA::SystemException)
{
    if( CORBA::is_nil(this->dm_RemoteObject) )
    {
	throw CORBA::BAD_INV_ORDER();
    }
    return( this->dm_RemoteObject->GetComputeTime() );
};

/** @copydoc Broker::RealTimeTask::SetComputeTime */
virtual void SetComputeTime(CORBA::ULong usecs)
    throw (CORBA::SystemException)
{
    if( CORBA::is_nil(this->dm_RemoteObject) )
    {
	throw CORBA::BAD_INV_ORDER();
    }
    this->dm_RemoteObject->SetComputeTime(usecs);
};

/** @copydoc Broker::RealTimeTask::ReportCPU */
virtual void ReportCPU(Broker::RealTimeTask_ptr rtt,
		       CORBA::ULong status,
		       CORBA::ULong advice)
    throw (CORBA::SystemException)
{
    if( CORBA::is_nil(this->dm_RemoteObject) )
    {
	throw CORBA::BAD_INV_ORDER();
    }
    this->dm_RemoteObject->ReportCPU(rtt, status, advice);
};
