#! /bin/sh

BROKER_ALLUP=${top_builddir}/allup/src/broker_allup
CBHEY=${top_builddir}/cbhey/src/cbhey

$BROKER_ALLUP &
ALLUP_PID="$!"

trap 'kill $ALLUP_PID' EXIT

sleep 2

##

run_test $CBHEY -l

grep_output_for "IDL:BrokerDelegates/Delegate:1.0" \
    "Unable to list supported interfaces?"

##

$CBHEY file://allup.ior create library with name ${top_builddir}/libbroker/src/.libs/libcpu-broker > cb.ior
$CBHEY file://cb.ior create manager with name dummy > manager.ior
$CBHEY file://cb.ior create stub-real-time-task with name dummy > srtt.ior

$CBHEY file://allup.ior create library with name ${top_builddir}/policies/src/libpolicies > policies.ior
$CBHEY file://policies.ior create strict-policy with name dummy > strict_policy.ior

$CBHEY file://allup.ior create library with name ${top_builddir}/delegates/src/.libs/libdelegates > delegates.ior

$CBHEY file://delegates.ior create real-time-task-delegate > rttd.ior
$CBHEY file://delegates.ior create real-time-task-delegate > rttd2.ior
$CBHEY file://delegates.ior create real-time-task-delegate > rttd3.ior

$CBHEY file://delegates.ior create strict-policy-delegate > spd.ior

##

run_test $CBHEY file://delegates.ior getsuites

check_output "Unable to getsuites of the library?" <<EOF
Property:  real-time-task-delegate
  Supported verbs: create
Create a RealTimeTaskDelegate object.

Property:  strict-policy-delegate
  Supported verbs: create
Create a StrictPolicyDelegate object.

EOF

##

run_test $CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://rttd.ior getsuites

check_output "Unable to getsuites of the delegate?" <<EOF
Property:  remote-object
  Supported verbs: get set
Get or set the object to delegate to.

Property:  insert
  Supported verbs: execute
delegate:object - The delegate to insert.

Insert another delegate between this object and the
remote object.

EOF

##

$CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://rttd.ior get remote-object > ro.ior
run_test $CBHEY file://ro.ior list

check_output "Unable to get remote-object?" <<EOF
Null object
EOF

##

$CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://spd.ior get remote-object > ro.ior
run_test $CBHEY file://ro.ior list

check_output "Unable to get remote-object?" <<EOF
Null object
EOF

##

run_test $CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://rttd.ior set remote-object to file://rttd2.ior

check_output "Unable to set remote-object?" <<EOF
ok
EOF

##

run_test $CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://rttd.ior get remote-object

check_output "Unable to get same remote-object?" < rttd2.ior

##

run_test $CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://rttd.ior get remote-object

check_output "Unable to get same remote-object (2)?" < rttd2.ior

##

run_test $CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://rttd.ior set remote-object to file://manager.ior

check_output "Able to set remote-object to a manager?" <<EOF
Caught Exception: BAD_PARAM (IDL:omg.org/CORBA/BAD_PARAM:1.0)
EOF

##

run_test $CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://rttd.ior get remote-object

check_output "Unable to get same remote-object (3)?" < rttd2.ior

##

run_test $CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://rttd.ior execute insert with delegate file://rttd3.ior
check_output "Unable to insert a delegate?" <<EOF
ok
EOF

##

run_test $CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://rttd.ior get remote-object

check_output "Unable to get inserted delegate?" < rttd3.ior

##

run_test $CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://rttd3.ior get remote-object

check_output "Unable to get interposed object?" < rttd2.ior

##

if test x"$OMNIIDL" != x""; then

    PYTHONPATH="${top_builddir}/delegates/src"
    PYTHONPATH="${PYTHONPATH}:${top_srcdir}/delegates/src"
    PYTHONPATH="${PYTHONPATH}:${top_builddir}/policies/src"
    PYTHONPATH="${PYTHONPATH}:${top_builddir}/libbroker/src"
    export PYTHONPATH
    
    ${PYTHON} ${top_srcdir}/delegates/test/py_delegates.py pya.ior pyp.ior &
    PY_PID="$!"

    trap 'kill $ALLUP_PID; kill $PY_PID' EXIT

    sleep 2

    ##

    run_test $CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://pya.ior set remote-object to file://srtt.ior

    check_output "Unable to set remote-object on python advocate?" <<EOF
ok
EOF

    ##

    run_test $CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://pya.ior get remote-object

    check_output "Unable to get remote-object on python advocate?" < srtt.ior

    ##

    run_test $CBHEY -c IDL:Broker/RealTimeTask:1.0 file://pya.ior execute begin-cpu-scheduling with manager file://manager.ior period 10000

    check_output "Unable to execute begin-cpu-scheduling on python advocate?" <<EOF
ok
EOF

    ##

    run_test $CBHEY -c IDL:Broker/RealTimeTask:1.0 file://pya.ior execute report-cpu with status 5000 advice 5000

    check_output "Unable to execute report-cpu on python advocate?" <<EOF
ok
EOF

    ##

    run_test $CBHEY -c IDL:Broker/RealTimeTask:1.0 file://pya.ior get compute

    check_output "Unable to get compute time from python advocate?" <<EOF
10000
EOF

    ##

    run_test $CBHEY -c IDL:Broker/RealTimeTask:1.0 file://pya.ior execute end-cpu-scheduling

    check_output "Unable to execute end-cpu-scheduling on python advocate?" <<EOF
ok
EOF

    ##

    run_test $CBHEY -c IDL:BrokerDelegates/Delegate:1.0 file://pyp.ior set remote-object to file://strict_policy.ior

    check_output "Unable to set remote object on python policy delegate?" <<EOF
ok
EOF

    ##

    run_test $CBHEY file://manager.ior set policy to file://pyp.ior

    check_output "Unable to set policy on manager?" <<EOF
ok
EOF

    ##

    run_test $CBHEY file://manager.ior execute add-task with task file://pya.ior period 100000

    check_output "Unable to add python advocate to the manager?" <<EOF
ok
EOF

    ##

    run_test $CBHEY -c IDL:Broker/RealTimeTask:1.0 file://pya.ior execute report-cpu with status 5000 advice 5000

    check_output "Unable to execute report-cpu on python advocate (2)?" <<EOF
ok
EOF

    ##

    run_test $CBHEY -c IDL:Broker/RealTimeTask:1.0 file://pya.ior get compute

    check_output "Unable to get compute time from python advocate (2)?" <<EOF
5000
EOF

    ##

    run_test $CBHEY file://manager.ior execute remove of task file://pya.ior

    check_output "Unable to remove python advocate?" <<EOF
ok
EOF

    ##

fi

##
