/*
 * instrumentation_test.c
 *
 * Copyright (c) 2003 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file instrumentation_test.c
 *
 * Test the instrumentation infrastructure.
 */

#include "config.h"

#include <stdlib.h>

#include "instrumentation.h"

#if defined(INSTR_test_data)
static struct iPoint INSTR_test_point = {
    INSTR_test_data
};
#endif

int main(int argc, char *argv[])
{
    int retval = 0;

    instrumentation_data.iid_OutputFileName = "-";
    atexit(iPrintPointsAtExit);

    {
	static double hrtime_test_history[8];
	static struct iPoint hrtime_test_point = {
	    "hrtime",
	    "test of hrtime() function",
	    0,
	    IPOINT_INIT_HISTORY(hrtime_test_history),
	    "%8.0f  ",
	};

	hrtime_t start, end;
	int lpc;
	
	for( lpc = 0; lpc < 10; lpc++ )
	{
	    volatile int delay;
	    
	    start = hrtime();
	    for( delay = 0; delay < 1000; delay++ );
	    end = hrtime();
	    iPostFloatData(&hrtime_test_point, (end - start));
	}
    }

    INSTR_test(&INSTR_test_point, {
	printf("Hello, World!\n");
    });

    INSTR_notest(&INSTR_notest_point, {
    });
    
    return( retval );
}
