/*
 * GlacialTaskAdvocate.hh
 *
 * Copyright (c) 2003 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file GlacialTaskAdvocate.hh
 *
 * Header file for the GlacialTaskAdvocate class.
 */

#ifndef _glacial_task_advocate_hh
#define _glacial_task_advocate_hh

#include <RealTimeTaskDelegateImpl.hh>

/**
 * An ExactTaskAdvocate that is slower to react to changes in the required
 * amount of CPU time.
 */
class GlacialTaskAdvocate : public virtual RealTimeTaskDelegateImpl
{

public:
    
    GlacialTaskAdvocate(void);

    virtual ~GlacialTaskAdvocate(void);

    /**
     * Compute a new processing time advice from the given status value.  The
     * glacial implementation will use the advice reported by the parent class
     * and temper the change by some factor.
     *
     * @param rtt The task object that was actually added to the manager.
     * @param status The CPU usage of the task in microseconds.
     * @param advice The amount of CPU time, in microseconds, that the
     * application would like for the next period.
     * @return A processing time with a smaller change than that reported by
     *         the parent.
     * @exception CORBA::BAD_INV_ORDER if the method is called without
     *            BeginCPUScheduling() being called first.
     */
    virtual void ReportCPU(Broker::RealTimeTask_ptr rtt,
			   CORBA::ULong status,
			   CORBA::ULong advice)
	throw (CORBA::SystemException);

private:

    /**
     * The last advice reported by this advocate.
     */
    CORBA::ULong gta_LastAdvice;

};

#endif
