/*
 * QuoAdvocate.hh
 *
 * Copyright (c) 2003 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file QuoAdvocate.hh
 *
 * Header file for the QuoAdvocate class.
 */

#ifndef _quo_advocate_hh
#define _quo_advocate_hh

#include <iostream>

#include <RealTimeTaskDelegateImpl.hh>
#include <quo/quoC.h>

/**
 * A Broker::RealTimeAdvocate that suggests the task gets the exact amount of
 * compute time as needed by the last period.
 */
class QuoAdvocate : public virtual RealTimeTaskDelegateImpl
{

public:

    QuoAdvocate(void);

    virtual ~QuoAdvocate(void);

    virtual void SetDelegateAttribute(const char *id,
				      const CORBA::Any &value)
	throw (CORBA::SystemException);

    virtual CORBA::Any *GetDelegateAttribute(const char *id)
	throw (CORBA::SystemException);

    virtual void ReportCPU(Broker::RealTimeTask_ptr rtt,
			   CORBA::ULong status,
			   CORBA::ULong advice)
	throw (CORBA::SystemException);

protected:

    /**
     * The QuO system condition that should be updated with the 'status' value
     * given in ReportCPU.
     */
    quo::ValueSC_var eta_Status;
    
    /**
     * The QuO system condition that should be updated with the 'advice' value
     * given in ReportCPU.
     */
    quo::ValueSC_var eta_Advice;
    
};

#endif
