/*
 * MaxDecayTaskAdvocate.cc
 *
 * Copyright (c) 2003 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is licensed under the terms of the GNU Public License.  
 * See the file "license.terms" for restrictions on redistribution 
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 */

/**
 * @file MaxDecayTaskAdvocate.cc
 *
 * Implementation of the MaxDecayTaskAdvocate class.
 */

#include "config.h"

#include "MaxDecayTaskAdvocate.hh"

/**
 * The default number of periods to wait before dropping the reservation to the
 * currently observed minimum.
 */
#define DECAY_AFTER 5

MaxDecayTaskAdvocate::MaxDecayTaskAdvocate(void)
{
    this->md_LastAdvice = 0;
    this->md_Decay = DECAY_AFTER;
}

MaxDecayTaskAdvocate::~MaxDecayTaskAdvocate(void)
{
}

void MaxDecayTaskAdvocate::ReportCPU(Broker::RealTimeTask_ptr rtt,
				     CORBA::ULong status,
				     CORBA::ULong advice)
    throw (CORBA::SystemException)
{
    if( CORBA::is_nil(this->dm_RemoteObject) )
    {
	throw CORBA::BAD_INV_ORDER();
    }
    
    if( advice >= this->md_LastAdvice )
    {
	this->md_Decay = DECAY_AFTER;
	this->md_SubMax = 0;
	advice += (CORBA::ULong)(0.01 * advice);
    }
    else if( this->md_Decay > 0 )
    {
	this->md_SubMax = max(this->md_SubMax, advice);
	this->md_Decay -= 1;
	advice = this->md_LastAdvice;
    }
    else if( this->md_Decay == 0 )
    {
	advice = (CORBA::ULong)(this->md_SubMax + (0.05 * this->md_SubMax));
	this->md_SubMax = 0;
	this->md_Decay = DECAY_AFTER;
    }
    this->md_LastAdvice = advice;
    this->RealTimeTaskDelegateImpl::ReportCPU(rtt, status, advice);
}
